The main NITF header object (sarpy.io.general.nitf_elements.nitf_head)
======================================================================

.. automodule:: sarpy.io.general.nitf_elements.nitf_head
    :members:
    :show-inheritance:
    :inherited-members:
